@@ -58,7 +58,7 @@ char* gStatmentKindStrs[kCommand+1] = {
     "x", "join", "select", "lines", "rows",
     "ary_new", "ary_add", "ary_erase", "ary_clear", 
     "hash_new", "hash_add", "hash_erase", "hash_clear",
-    "match", "scan", "erase", "pos", "sub",  
+    "match", "scan", "erase", "sub",  
     "read",
     "cd", 
     "add", "del",  "selector", "max", "min", "extname", 
@@ -2734,7 +2734,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.2.8", 1);
+    setenv("SAPHIRE_VERSION", "1.3.0", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
